@@ -35,10 +35,14 @@
  * - not declared in the corresponding header
  *
  */
-
 #include <linux/version.h>
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,33)
+#include <generated/autoconf.h>
+#else
 #include <linux/autoconf.h>
+#endif
 #include <linux/poll.h>
+#include <linux/signal.h>
 #include <asm/io.h>
 
 #include "kcl_config.h"
@@ -122,23 +126,28 @@ void ATI_API_CALL KCL_IO_FASYNC_Terminate(
     kill_fasync ((struct fasync_struct**)pasync_queue, SIGIO, POLLIN);
 }
 
-
 /** \brief Map device i/o mem to be used by CPU
  ** \param offset [in] Physical address of the device i/o memory
  ** \param size [in] Number of bytes to map
- ** \param nocache [in] 1 to map without caching, 0 to map with caching
+ ** \param type [in] one of the KCL_IOREMAPTYPE_xxx types
  ** \return Logical address (not guaranteed to be virtual)
  */
-void* ATI_API_CALL KCL_IO_MEM_Map(unsigned long offset,
+void* ATI_API_CALL KCL_IO_MEM_Map(unsigned long long offset,
                                   unsigned long size,
-                                  int nocache)
+                                  int type)
 {
-    if (nocache)
+    switch (type)
     {
+    case KCL_IOREMAPTYPE_WriteCombine:
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,26)
+        return ioremap_wc(offset, size);
+#endif
+
+    case KCL_IOREMAPTYPE_NoCache:
         return ioremap_nocache(offset, size);
-    }
-    else
-    {
+
+    case KCL_IOREMAPTYPE_Default:
+    default:
         return ioremap(offset, size);
     }
 }
@@ -151,10 +160,6 @@ void ATI_API_CALL KCL_IO_MEM_Unmap(void* pt)
     iounmap(pt);
 }
 
-/** \brief Write byte to port
- ** \param value [in] Value to write
- ** \param port [in] Port number
- */
 void ATI_API_CALL KCL_IO_PORT_WriteByte(unsigned char value, unsigned short port)
 {
     outb(value, port);
@@ -187,5 +192,3 @@ unsigned int ATI_API_CALL KCL_IO_PORT_ReadDword(unsigned short port)
     return inl(port);
 }
 
-
-
