@@ -129,11 +129,14 @@ extern "C" {
 #endif
 
 #ifndef GLX_ARB_create_context
-#define GLX_CONTEXT_DEBUG_BIT_ARB          0x00000001
-#define GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB 0x00000002
-#define GLX_CONTEXT_MAJOR_VERSION_ARB      0x2091
-#define GLX_CONTEXT_MINOR_VERSION_ARB      0x2092
-#define GLX_CONTEXT_FLAGS_ARB              0x2094
+#define GLX_CONTEXT_DEBUG_BIT_ARB                 0x00000001
+#define GLX_CONTEXT_FORWARD_COMPATIBLE_BIT_ARB    0x00000002
+#define GLX_CONTEXT_MAJOR_VERSION_ARB             0x2091
+#define GLX_CONTEXT_MINOR_VERSION_ARB             0x2092
+#define GLX_CONTEXT_FLAGS_ARB                     0x2094
+#define GLX_CONTEXT_PROFILE_MASK_ARB              0x9126
+#define GLX_CONTEXT_CORE_PROFILE_BIT_ARB          0x00000001
+#define GLX_CONTEXT_COMPATIBILITY_PROFILE_BIT_ARB 0x00000002
 #endif
 
 #ifndef GLX_SGIS_multisample
@@ -375,7 +378,22 @@ extern "C" {
 #ifndef GLX_NV_swap_group
 #endif
 
+#ifndef GLX_AMD_gpu_association
+#define GLX_GPU_VENDOR_AMD                 0x1F00
+#define GLX_GPU_RENDERER_STRING_AMD        0x1F01
+#define GLX_GPU_OPENGL_VERSION_STRING_AMD  0x1F02
+#define GLX_GPU_FASTEST_TARGET_GPUS_AMD    0x21A2
+#define GLX_GPU_RAM_AMD                    0x21A3
+#define GLX_GPU_CLOCK_AMD                  0x21A4
+#define GLX_GPU_NUM_PIPES_AMD              0x21A5
+#define GLX_GPU_NUM_SIMD_AMD               0x21A6
+#define GLX_GPU_NUM_RB_AMD                 0x21A7
+#define GLX_GPU_NUM_SPI_AMD                0x21A8
+#endif
 
+#ifndef GLX_EXT_buffer_age
+#define GLX_BACK_BUFFER_AGE_EXT                0x20F4
+#endif
 /*************************************************************/
 
 #ifndef GLX_ARB_get_proc_address
@@ -826,6 +844,78 @@ typedef void ( * PFNGLXRELEASETEXIMAGEEXTPROC) (Display *dpy, GLXDrawable drawab
 #define GLX_NV_swap_group 1
 #endif
 
+#ifndef GLX_AMD_gpu_association
+#define GLX_AMD_gpu_association 1
+#ifdef GLX_GLXEXT_PROTOTYPES
+extern unsigned int  glXGetGPUIDsAMD(unsigned int maxCount, unsigned int *ids);
+extern int   glXGetGPUInfoAMD(unsigned int id, int property, GLenum dataType,
+                           unsigned int size, void *data);
+extern unsigned int  glXGetContextGPUIDAMD(GLXContext ctx);
+extern GLXContext glXCreateAssociatedContextAMD(unsigned int id, GLXContext share_list);
+extern GLXContext glXCreateAssociatedContextAttribsAMD(unsigned int id, GLXContext share_context,
+                                               const int *attribList);
+extern Bool  glXDeleteAssociatedContextAMD(GLXContext ctx);
+extern Bool  glXMakeAssociatedContextCurrentAMD(GLXContext ctx);
+extern GLXContext glXGetCurrentAssociatedContextAMD(void);
+extern void  glXBlitContextFramebufferAMD(GLXContext dstCtx, GLint srcX0, GLint srcY0,
+                                       GLint srcX1, GLint srcY1, GLint dstX0,
+                                       GLint dstY0, GLint dstX1, GLint dstY1,
+                                       GLbitfield mask, GLenum filter);
+#endif
+typedef unsigned int (*PFNGLXGETGPUIDSAMDPROC)(unsigned int maxCount, unsigned int *ids);
+typedef int   (*PFNGLXGETGPUINFOAMDPROC)(unsigned int id, int property, GLenum dataType,
+                           unsigned int size, void *data);
+typedef unsigned int (*PFNGLXGETCONTEXTGPUIDAMDPROC)(GLXContext ctx);
+typedef GLXContext (*PFNGLXCREATEASSOCIATEDCONTEXTAMDPROC)(unsigned int id, GLXContext share_list);
+typedef GLXContext (*PFNGLXCREATEASSOCIATEDCONTEXTATTRIBSAMDPROC)(unsigned int id, GLXContext share_context,
+                                               const int *attribList);
+typedef Bool (*PFNGLXDELETEASSOCIATEDCONTEXTAMDPROC)(GLXContext ctx);
+typedef Bool (*PFNGLXMAKEASSOCIATEDCONTEXTCURRENTAMDPROC)(GLXContext ctx);
+typedef GLXContext (*PFNGLXGETCURRENTASSOCIATEDCONTEXTAMDPROC)(void);
+typedef void  (*PFNGLXBLITCONTEXTFRAMEBUFFERAMDPROC)(GLXContext dstCtx, GLint srcX0, GLint srcY0,
+                                       GLint srcX1, GLint srcY1, GLint dstX0,
+                                       GLint dstY0, GLint dstX1, GLint dstY1,
+                                       GLbitfield mask, GLenum filter);
+#endif
+
+#ifndef GLX_EXT_buffer_age
+#define GLX_EXT_buffer_age  1
+#endif
+
+
+#ifndef GLX_AMD_display_post_processing
+#define GLX_AMD_display_post_processing
+extern GLXContext glXGetPostProcessContextAMD(Display *dpy);
+extern GLXDrawable glXGetPostProcessDrawableAMD(Display *dpy);
+extern unsigned int glXEnablePostProcessAMD(GLboolean enable);
+extern unsigned int glXSetDesktopSurfaceSizeAMD(unsigned int width, unsigned int height, unsigned int defaultPresentTexture );
+extern unsigned int glXPresentDesktopAMD(unsigned int presentTexture, unsigned int displayIndex, const unsigned int *attrib_list );
+#define GLX_WAIT_FOR_PREVIOUS_VSYNC             0x21A9
+#define GLX_SUCCEEDED                           0x21AA
+//Returned by glXPresentDesktopAMD:
+#define GLX_DESKTOP_CHANGED                     0x21AB
+#define GLX_DESKTOP_SURFACE_LOST                0x21AC
+#define GLX_PRESENT_SURFACE_LOST                0x21AD
+#define GLX_INCONSISTENT_PRESENT_SURFACES       0x21AE
+#define GLX_POST_PROCESSING_DISABLED            0x21AF
+#define GLX_BAD_SURFACE                         0x91C1
+//Returned by glXEnablePostProcessAMD:
+#define GLX_POST_PROCESSING_NOT_SUPPORTED       0x91C2
+//Returned by glXSetDesktopSurfaceSizeAMD:
+#define GLX_DESKTOP_SIZE_CHANGE_NOT_ALLOWED     0x91C3
+#define GLX_DESKTOP_SIZE_NOT_SUPPORTED          0x9cC0
+//Accepted by the <attribute> parameter of glXQueryDrawable:
+#define GLX_DISPLAY_COUNT                       0x91C4
+#define GLX_CONTEXT_POST_PROCESS_AMD            0x3050
+#endif
+
+#ifndef GLX_ARB_create_context_robustness
+#define GLX_ARB_create_context_robustness
+#define GLX_CONTEXT_ROBUST_ACCESS_BIT_ARB           0x00000004
+#define GLX_NO_RESET_NOTIFICATION_ARB               0x8261
+#define GLX_LOSE_CONTEXT_ON_RESET_ARB               0x8252
+#define GLX_CONTEXT_RESET_NOTIFICATION_STRATEGY_ARB 0x8256
+#endif
 
 #ifdef __cplusplus
 }
